import { AddExistingExperimentDataOptions, AddExperimentCallsProps, AssignByPointsOptions, AssignOptions, AsyncStatus, ConstructorOptions, EntityIds, ExistingData, ExperimentAttributeValue, GetAssignmentOptions, GetPropertiesResponse, LoggerOptions, SDKAssignment, TrackerOptions, TypeData, AssignmentsMap } from './types';
/** Class providing MDB Experiment SDK functionality */
export default class ExperimentSDK<T extends TypeData> {
    #private;
    /**
     * @description
     * Create an instance of the SDK. It's highly recommended to pass in a type interface
     * as well for stronger typing of experiment data and log properties.
     *
     * Intended usage:
     * Called by the ExperimentSDKClient class in index.ts. Should never be called directly by a user.
     *
     * @param {ConstructorOptions} options - Required
     *
     * @return {ExperimentSDK} An instance of the class
     *
     * @throws Can throw an error if entityIds, loggerOptions, or trackerOptions are invalid.
     *
     * @example
     * const options: ConstructorOptions = {
     *  entityIds: { orgId: 'iAmAnOrgId' },
     *  environment: Environment.DEV,
     * };
     *
     * enum ExperimentName {
     *  EXP_ONE = 'expOne',
     * };
     *
     * enum ExperimentVariantName {
     *  EXP_VARIANT_ONE = 'expVariantOne',
     * };
     *
     * enum ExperimentAttributeName {
     *  SHOW_LEFT_NAV_LINK = 'showLeftNavLink',
     * };
     *
     * enum AllocationPointName {
     *  CLUSTER_CARD_PAGE = 'CLUSTER_CARD_PAGE',
     * };
     *
     * enum LoggerTeam {
     *  Team1 = 'Team 1',
     * };
     *
     * interface Types {
     *  experimentName: ExperimentName,
     *  experimentVariantName: ExperimentVariantName,
     *  experimentAttributeName: ExperimentAttributeName,
     *  allocationPointName: AllocationPointName,
     *  loggerTeam: LoggerTeam,
     * }
     *
     * const experimentSDK = new ExperimentSDK<Types>(options);
     */
    constructor(options: ConstructorOptions<T>);
    /**
       * @description
       * Retrieves non-experiment-data-related properties of the SDK. Returns deep clones of the props.
       *
       * Intended usage:
       * Primarily for debugging and testing purposes. Not intended to allow mutating the instance props.
       *
       * @return
       * An object containing copies of selected properties of the SDK:
       * entityIds, loggerOptions, trackerOptions, and environment
       *
       * @example
       * const res = sdk.getProperties();
       * console.log(res);
       * {
        entityIds: { orgId: 'iAmAnOrgId', groupId: 'iAmAGroupId', userId: 'iAmAUserId' },
        loggerOptions: { logger: { log: [Function: log] }, defaultTeam: LoggerTeam.Team1 },
        trackerOptions: { tracker: { track: [Function: track] } },
        environment: 'dev'
      }
       *
       */
    getProperties(): Readonly<GetPropertiesResponse<T>>;
    /**
     * @description
     * If the updated entityIds are different from the existing entityIds, update the existing entityIds
     * and clear assignmentsMap,experimentAttributesMap, assignmentCalls, allocationPointCalls.
     * If the updated entityIds are the same, then no changes are made
     *
     * Intended usage:
     * Updates the existing entityIds and clears existing experiment data
     *
     * @return The SDK itself
     *
     * @throws Can throw an error if the entityIds are invalid
     *
     * @example
     * const updatedEntities =  { orgId: 'iAmAnOrgId', groupId: 'iAmAGroupId', userId: 'iAmAUserId' };
     * const res = sdk.updateEntityIds(updatedEntities);
     * const newSdkIds = res.getProperties().entityIds;
     * console.log(newSdkIds);
     * { orgId: 'iAmAnOrgId', groupId: 'iAmAGroupId', userId: 'iAmAUserId' }
     */
    updateEntityIds(entities: EntityIds): ExperimentSDK<T>;
    /**
     * @description Updates loggerOptions on the SDK
     *
     * Intended usage:
     * Updates the logger options for logging within the SDK
     *
     * @param {LoggerOptions} loggerOptions - Required
     *
     * @return {SdkInstance} An instance of the class
     *
     * @throws Can throw an error if the loggerOptions are invalid.
     *
     * @example
     * enum LoggerTeam {
     *  Team1 = 'Test Team 1',
     * };
     *
     * const updatedSDK = sdk.updateLoggerOptions({
     *  logger: loggerClient, // In MMS, this will be bugsnag
     *  defaultTeam: LoggerTeam.Team1
     * })
     *
     * const newSdkLoggerOptions = res.getProperties().loggerOptions;
     * console.log(newSdkLoggerOptions);
     * { logger: loggerClient, defaultTeam: LoggerTeam.Team1 }
     */
    updateLoggerOptions(loggerOptions: LoggerOptions<T['loggerTeam']>): this;
    /**
     * @description
     * Update the Tracker object that makes analytics calls
     *
     * Intended usage:
     * Updates the Tracker object that makes analytics calls if it needs to be changed,
     * or set if it was not set during initialization
     *
     * @param {TrackerOptions} trackerOptions - Required
     *
     * @return {SdkInstance} An instance of the class
     *
     * @throws Can throw an error if the trackerOptions are invalid.
     *
     * @example
     * const newTracker =  { track: () => {}}; // In MMS, this will be Heliotrope
     * const newTrackerOptions = { tracker: newTracker };
     * const newSdkTrackerOptions = experimentSdk.getProperties().trackerOptions;
     * console.log(newSdkTrackerOptions);
     * { tracker: { track: () => {} } }
     */
    updateTrackerOptions(trackerOptions: TrackerOptions<T['experimentViewedProps']>): ExperimentSDK<T>;
    /**
     * @description
     * Allows passing in existing experiment data (such as assignments, experiment attributes,
     * and ghost assignments) to populate the SDK state. This function checks if
     * existing assignments, ghost assignments, or experiment attributes for the entity are attempting to
     * be overwritten and if so, logs a warning and prioritizes the SDK's existing data.
     * It also takes care of transforming "string" experiment attribute values into numbers and
     * booleans as needed.
     *
     * This function has the added functionality of loading in any experiment overrides
     * provided by the FEdEx (go/fedex; Front End Experiment Editor) experiment editor extension. This
     * behavior is only activated when the extension is active and writing overrides to sessionStorage.
     *
     * Intended usage:
     * Useful if the client has data about an entity's assignments from another data store
     * (such as the MMS "params" call) that it would like to make the SDK aware of
     *
     * @param {ExistingData} existingData - Required. Object with optional assignments,
     * experimentAttributes, and ghostAssignments properties.
     * @param {AddExistingExperimentDataOptions} options - Optional. Object with additional optional props,
     * such as a "team" override for logging purposes.
     *
     * @return {SdkInstance} An instance of the class
     *
     * @example
     * // ex 1: passing in full existingData object
     * const { assignments, experimentAttributes, ghostAssignments } = clientApi.fetchExistingData(); // an external api
     * experimentSdk.addExistingExperimentData({assignments, experimentAttributes, ghostAssignments },
     * { team: LoggerTeam.Team1 });
     *
     * // ex 2: passing in an assignment
     * const existingServerAssignment = {
     *   assignmentDate: '1658340252128',
     *   entityId: '621509aae911cb2e37ba91ca',
     *   entityType: 'ORG',
     *   id: '62d8439c9ce6473793cff6ca',
     *   tag: 'activation',
     *   testId: '62bb810b61be7d017fcc2198',
     *   testName: 'expOne',
     *   testGroupId: 'variantOne,
     *   testGroupDatabaseId: '62bb810b61be7d017fcc2196',
     * };
     *
     * experimentSdk.addExistingExperimentData({
     *  assignments: [existingServerAssignment]
     * });
     *
     * // ex 3: passing in an experiment attribute
     * const existingAttribute = {
     *  showLeftNavLink: 'false',
     * };
     *
     * experimentSdk.addExistingExperimentData({
     *  experimentAttributes: existingAttribute,
     * });
     */
    addExistingExperimentData(existingData: Readonly<ExistingData<T>>, options?: AddExistingExperimentDataOptions<T['loggerTeam']>): ExperimentSDK<T>;
    /**
     * @description
     * Allows user to pass in a function to be called with all assignments, whenever the #assignmentsMap is updated.
     *
     * Intended usage:
     * Allows for pubsub access to experiment assignments. Subscribers will have access to a clone of the assignment data.
     *
     * @param {function} subscriberCallback - Required. Function that will be called with {@link AssignmentsMap}, whenever
     * a new assignment occurs.
     *
     * @return A function that can be called to unsubscribe from #assignmentsMap updates.
     *
     * @example
     * const subscriptionCb = (assignmentsMap) => {
     *    console.log('AB test AssignmentsMap has changed', assignmentsMap)
     * };
     *
     * const unsubscribe = subscribeToAssignmentsMap(subscriptionCb);
     *
     * await sdk.assign(ExperimentName.EXP_ONE);
     * // subscriptionCb will execute here, displaying the console log with the updated assignmentsMap.
     *
     * unsubscribe();
     *
     * await sdk.assign(ExperimentName.EXP_TWO);
     * // subscriptionCb will not execute here, as the subscription has been removed.
     *
     */
    subscribeToAssignmentsMap(subscriberCallback: (assignmentsMap: AssignmentsMap<T>) => void): () => void;
    /**
     * @description
     * Retrieves assignment data for a particular experiment name. This function will wait for the assign
     * and assignByPoints function to finish retrieving data and return the assignment, or a Promise that
     * resolves with null if entity is not in the experiment. If assignment data for an experiment name has not been
     * or is not being retrieved by the assign or assignByPoints function, this function will make a GET request to MMS
     * backend to get the assignment.
     * If no assignment is found, this function will return a promise that resolves with null.
     *
     * If trackIsInSample (parameter of function) is set to true and the entity is in the experiment sample,
     * trackIsInSample() will be called, which fires an Experiment Viewed event with default props and
     * trackIsInSampleCustomProps (part of the 'options' parameter of this function).
     *
     * If there is an error, this function will log a warning and return a promise that resolves with null.
     * (It will not throw an error.)
     *
     * This is the ONLY function in the SDK that retrieves experiment data.
     *
     * Intended usage:
     * Used to get an entity's assignment information for an experiment.
     *
     * @param {ExperimentName} experimentName - Required
     * @param {boolean} trackIsInSample - Required
     * @param {GetAssignmentOptions} options - Optional. User of this function can pass in an optional
     * customProps object if they want the Experiment Viewed event to have custom properties and/or pass in a team
     * if they want the logger to log for a specific team
     *
     * @return A Promise that resolves to either an {@link SDKAssignment} object or null (if the assignment info does not
     * exist, because entity is not in experiment, data has not been fetched, or the pending assignment call errored out).
     * Even if the Promise resolves to an SDKAssignment object, the entity may not be in the experiment
     * --check {@link SDKAssignment.assignmentData.isInSample} to be sure.
     *
     * @example
     * const experimentName: ExperimentName = ExperimentName.EXP_ONE;
     * const getAssignmentOptions: GetAssignmentOptions<Types> = {
          trackIsInSampleCustomProps:{
            firstProperty: 1,
            secondProperty: '2',
          },
          team: 'Team 1',
        }
     * const res: SDKAssignment<Types['experimentName'], Types['experimentVariantName']> | null =
     *                                               await sdk.getAssignment(experimentName, false, getAssignmentOptions);
     * console.log(res);
     *  {
        assignmentData: { isInSample: true, variant: 'expVariantOne' },
        experimentData: {
          assignmentDate: '1658340252128',
          entityId: '621509aae911cb2e37ba91ca',
          entityType: 'ORG',
          id: '62d8439c9ce6473793cff6ca',
          tag: 'activation',
          testId: '62bb810b61be7d017fcc2198',
          testName: 'expOne',
          testGroupId: 'expVariantOne',
          testGroupDatabaseId: '62bb810b61be7d017fcc2196'
        }
      }
     *
     */
    getAssignment(experimentName: T['experimentName'], trackIsInSample: boolean, options?: GetAssignmentOptions<T>): Promise<SDKAssignment<T['experimentName'], T['experimentVariantName']> | null>;
    /**
     * @description
     * DO NOT USE!
     * Gets a stored assignment object for a given experiment name.
     * This is only meant to be used by internal tools! In real world applications,
     * you should always use the async getAssignment function, to ensure that a cache miss is
     * never misinterpreted as a null assignment.
     * @param {T['experimentName']} experimentName The name of the experiment
     * @return The assignment object if it exists in the cache, or null if not
     */
    unsafe_getCachedAssignment(experimentName: T['experimentName']): SDKAssignment<T['experimentName'], T['experimentVariantName']> | null;
    /**
     * @description
     * Given an experiment attribute name and a fallback value, returns the value for attributeName from the
     * local SDK state experimentAttributesMap, or the fallback value if none exists
     *
     * Intended usage:
     * To retrieve experiment attributes.
     *
     * @param attributeName - Required. The attribute name.
     * @param {ExperimentAttributeValue} fallbackValue - Required. The fallback value to be returned if attributeName does
     * not exist in local SDK state experimentAttributesMap.
     *
     * @return An ExperimentAttributeValue for attributeName or fallbackValue if none exists.
     *
     * @example
     * const attr: ExperimentAttributeValue = sdk.getExperimentAttribute(
     *   ExperimentAttributeName.SHOW_LEFT_NAV_LINK,
     *   false
     * );
     * console.log(attr);
     * // true
     */
    getExperimentAttribute(attributeName: T['experimentAttributeName'], fallbackValue: ExperimentAttributeValue): ExperimentAttributeValue;
    /**
     * @description
     * Given an experiment name, returns a Promise that is successfully resolved if the experiment is
     * successfully assigned, via the API if needed, for the SDK entity.
     *
     * If the API call has an error during assignment, this function should log the error message
     * and return a rejected Promise with the error. In these cases, the function will "clean up" the errored API call
     * so that the assignment can be reattempted by another "assign" call later if the user wishes.
     *
     * If there is an existing Promise for the experiment, the function will not make an API call and will return
     * the existing Promise. If there is no existing Promise but the assignment or ghost assignment already exists,
     * the function will not make an API call and a resolved Promise will be returned.
     *
     * CAN make a POST API call.
     * (For more information on the POST API call, see the
     * [wiki](https://wiki.corp.mongodb.com/display/MMS/MDB+Experiment+JS+SDK+Usage))
     *
     * Does NOT return assignment information--users should use the getAssignment function for that.
     *
     * Intended usage:
     * Assign the SDK entity for an experiment.
     * Can only take 1 experiment name per call. (If you are looking to pass multiple experiment names in 1 call,
     * perhaps that means this experiment allocation point should be a reusable allocation point.)
     *
     * @param experimentName - Required. An experiment name string.
     * @param {AssignOptions} options - Optional. Object with additional optional props, such as a "team" override
     * for logging purposes and a timeoutMs prop to define the API timeout.
     *
     * @return A Promise that resolves to an AsyncStatus object. If the Promise resolves, the AsyncStatus
     * object should represent success. In case of error, the Promise will reject.
     *
     * @throws Can throw an error if the API call throws an error.
     *
     * @example
     * const experimentName: ExperimentName = ExperimentName.EXP_ONE;
     *
     * const options: AssignOptions<Types['loggerTeam']> = {
     *  team: LoggerOptions.Team1,
     * };
     *
     * try {
     *  await sdk.assign(experimentName, options);
     * } catch (e) {
     *  // error handling in case the promise rejects. In this case, assume
     *  // the assignment data is not available in the SDK. Can retry, bubble up the error, etc.
     * }
     *
     * // at this point, can assume assignment info for this experiment is in the SDK so can retrieve the assignment
     * const assignment: SDKAssignment<Types['experimentName'], Types['experimentVariantName']> | null =
     *  await sdk.getAssignment(
     *    ExperimentName.EXP_ONE,
     *    true,
     *    options as GetAssignmentOptions<Types>
     *  );
     * // see getAssignment documentation for more details on using that function
     */
    assign(experimentName: T['experimentName'], options?: AssignOptions<T['loggerTeam']>): Promise<AsyncStatus>;
    /**
     * @description
     * Given an array of allocation point names, returns a Promise that is successfully resolved if all the experiments
     * associated with the given points are successfully assigned via the API for the SDK entity.
     * If ANY of the points in the given array is NOT successfully assigned, this function should log the error message
     * and return a rejected Promise with the error. In these cases, the function will "clean up" the errored API call
     * so that the point assignment can be reattempted by another "assignByPoints" call later if the user wishes.
     * If a point was previously successfully assigned or if the promise is currently pending,
     * the function will not make another API call for that point and will use the existing Promise for that point.
     *
     * CAN make a POST API call.
     * (For more information on the POST API call, see the
     * [wiki](https://wiki.corp.mongodb.com/display/MMS/MDB+Experiment+JS+SDK+Usage))
     *
     * Does NOT return assignment information--users should use the getAssignment function for that.
     *
     * Intended usage:
     * Assign entities for experiments configured to use reusable allocation points.
     * Can take multiple points in 1 request.
     *
     * @param allocationPoints - Required. An array of allocation point name strings.
     * @param {AssignByPointsOptions} options - Optional. Object with additional optional props, such as a "team" override
     * for logging purposes and a timeoutMs prop to define the API timeout.
     *
     * @return A Promise that resolves to an array of AsyncStatus objects. If the Promise resolves, all the AsyncStatus
     * objects should represent success. In case of error, the Promise will reject.
     *
     * @throws Can throw an error if the API call throws an error.
     *
     * @example
     * const allocationPointsArray: Array<AllocationPointName> = [
     *  AllocationPointName.CLUSTER_CARD_PAGE,
     *  AllocationPointName.REGISTRATION_SUCCESS_PAGE,
     * ];
     *
     * const options: AssignByPointsOptions<Types['loggerTeam']> = {
     *  team: LoggerTeam.Team1,
     * };
     *
     * try {
     *  await sdk.assignByPoints(allocationPointsArray, options);
     * } catch (e) {
     *  // error handling in case the promise rejects. In this case, assume
     *  // the assignment data is not available in the SDK. Can retry, bubble up the error, etc.
     * }
     *
     * // at this point, can assume assignment information for those points is in the SDK so can retrieve assignments
     * const assignment: SDKAssignment<Types['experimentName'], Types['experimentVariantName']> | null =
     *  await sdk.getAssignment(
     *    'experiment_that_was_allocated_with_allocation_points',
     *    true,
     *    options as GetAssignmentOptions<Types>
     *  );
     * // see getAssignment documentation for more details on using that function
     */
    assignByPoints(allocationPoints: Array<T['allocationPointName']>, options?: AssignByPointsOptions<T['loggerTeam']>): Promise<Array<AsyncStatus>>;
    /**
     * @description
     * Submits an "Experiment Viewed" or "Experiment GhostViewed" event with the client's tracker (if any).
     * Sends through default props ({@link ExperimentViewedBaseEvent}) and any custom props defined.
     * Will wait for relevant pending assignment calls to resolve to get assignment data.
     * (If there is an error, will log it but try to continue.) If there isn't a tracker or if
     * the assignment data or assignment call doesn't exist, it will log a warning and result in a no-op.
     *
     * Any error encountered in the client's track call will be bubbled up.
     *
     * Intended usage:
     * Fires the "Experiment Viewed" event using the client's tracker, if the client tracker
     * has been initialized and the entity is in the experiment, OR
     * Fires the "Experiment GhostViewed" event using the client's tracker, if the client tracker
     * has been initialized and the entity is in an Experiment Holdout but has a ghost assignment
     * for the experiment.
     *
     * @param {ExperimentName} experimentName - Required
     * @param {Object} customProps - Optional. User of this function can pass in an optional
     * customProps object if they want the Experiment Viewed/GhostViewed event to have custom
     * properties in addition to the default experiment props ({@link ExperimentViewedBaseEvent})
     *
     * @return {Promise<AsyncStatus|null>}
     * If there is a no op, returns a Promise that resolves with null.
     * Else if there is an error with the client's track call, throws an error.
     * Else if there is no error and track was called successfully, returns a Promise
     * that resolves with a 2XX code.
     *
     * @throws Can throw an error if the registered Tracker's track function throws an error.
     *
     * @example
     * const experimentName = "experimentNameExample";
     * const customProps =  { property1: true, property2: 0 };
     * const res: <AsyncStatus | null> = await sdk.trackIsInSample(experimentName, customProps);
     * if(res?.statusCode === 200) {
     *   console.log("track call succeeded");
     * }
     */
    trackIsInSample(experimentName: T['experimentName'], customProps?: T['experimentViewedProps'], team?: string): Promise<AsyncStatus | null>;
    /**
     * @description
     * Intended for TESTING USAGE ONLY. Populates the #assignmentCalls and #allocationPointCalls maps.
     * This function only works in DEV and LOCAL environments.
     *
     * Intended usage:
     * Used for tests for setting up SDK internal state to test certain scenarios.
     *
     * @param {AddExperimentCallsProps} - Required. an object containing optional assignmentCalls and
     * allocationPointCalls props
     */
    addExperimentCalls({ assignmentCalls, allocationPointCalls }: AddExperimentCallsProps<T>): void;
}
//# sourceMappingURL=ExperimentSDK.d.ts.map