import ExperimentSDK from './ExperimentSDK';
import { ConstructorOptions, TypeData } from './types';
export * as types from './typesExported';
/**
 * Static class allowing the creation of the SDK.
 */
export default class ExperimentSDKClient {
    #private;
    private constructor();
    /**
     * @description
     * Static method that returns an SDK object. Enforces singleton behavior (aka will only create
     * 1 SDK object instance--if one is already created, will return the existing one).
     *
     * It's highly recommended to pass in a type interface for stronger typing of experiment data and log properties.
     *
     * @see [our internal wiki](https://wiki.corp.mongodb.com/display/MMS/MDB+Experiment+JS+SDK+Usage)
     * for more info on how to set up an experiment.
     *
     * Intended usage: primary function a user calls to get the SDK.
     * Returns ExperimentSDK for use with experimentation functionality.
     *
     * @param options {@link types.ConstructorOptions} - Required
     * @return {ExperimentSDK} The singleton SDK instance.
     *
     * @example
     * const options: ConstructorOptions = {
     *  entityIds: { orgId: 'iAmAnOrgId' },
     *  environment: Environment.DEV,
     * };
     *
     * enum ExperimentName {
     *  EXP_ONE = 'expOne',
     * };
     *
     * enum ExperimentVariantName {
     *  EXP_VARIANT_ONE = 'expVariantOne',
     * };
     *
     * enum ExperimentAttributeName {
     *  SHOW_LEFT_NAV_LINK = 'showLeftNavLink',
     * };
     *
     * enum AllocationPointName {
     *  CLUSTER_CARD_PAGE = 'CLUSTER_CARD_PAGE',
     * };
     *
     * enum LoggerTeam {
     *  Team1 = 'Team 1',
     * };
     *
     * interface Types extends types.TypeData {
     *  experimentName: ExperimentName,
     *  experimentVariantName: ExperimentVariantName,
     *  experimentAttributeName: ExperimentAttributeName,
     *  allocationPointName: AllocationPointName,
     *  loggerTeam: LoggerTeam,
     * }
     *
     * const sdk = ExperimentSDKClient.create<Types>(options);
     */
    static create<T extends TypeData>(options: ConstructorOptions<T>): ExperimentSDK<T>;
    /**
     * @description
     * Gets the singleton SDK instance or null if that value hasn't been set. (It should be created and set with
     * {@link create}.)
     *
     * Intended usage: gets the SDK instance for use. If you're not sure if the SDK instance has been created in the
     * application, then use {@link create} instead.
     *
     * @return sdk - the SDK instance singleton, or null if no SDK instance has been initialized
     *
     * @example
     * const sdk = ExperimentSDKClient.getSDKInstance();
     * // since sdk value can be null, can use optional chaining or check sdk and if null, either
     * // 1) throw error or
     * // 2) call "create" with constructor options
     * sdk?.getProperties();
     */
    static getSDKInstance<T extends TypeData>(): ExperimentSDK<T> | null;
}
//# sourceMappingURL=index.d.ts.map