import React from 'react';
import { TypeData } from '../types';
import { ExperimentSDKContextType, ExperimentSDKProviderProps } from './types';
/**
 * A React Context for the ExperimentSDK; child components of the {@link ExperimentSDKProvider}
 * will have access to these values as long as they set their context to ExperimentSDKContext via
 * ".contextType" or "useContext".
 *
 * NOTE: This value should NOT be null if the React SDK functions are to be used.
 * If it is null, that may be due to:
 * 1. The context is being used in a component that is NOT a child of the {@link ExperimentSDKProvider} component, or
 * 2. The SDK object passed into the {@link ExperimentSDKProvider} was null. If you're seeing this behavior, check
 * that SDK instantiation (via ExperimentSDKClient.create) occurred before ExperimentSDKProvider was created. Both of
 * these functions are synchronous, but be aware if the SDK is created in an async block, that may throw off the order.
 *
 * This context will show up as "ExperimentSDKContext" in the
 * {@link https://chrome.google.com/webstore/detail/react-developer-tools/fmkadmapgofadopljbjfkapdkoienihi?hl=en|React DevTools}
 *  component tree.
 */
export declare const ExperimentSDKContext: React.Context<ExperimentSDKContextType<TypeData>>;
/**
 * @description
 * The React Provider for the ExperimentSDK. Child components of the Provider will have access to the
 * {@link ExperimentSDKContext} values as long as they set their context to ExperimentSDKContext via
 * ".contextType" or "useContext". If a component is using any of the React hook functions defined in
 * mdb-experiement-js/react, make sure the component is a child of the ExperimentSDKContext.Provider (this component)
 * and the Provider was initialized with a non-null {@link ExperimentSDK} instance.
 *
 * (An easy way to confirm is via the
 * {@link https://chrome.google.com/webstore/detail/react-developer-tools/fmkadmapgofadopljbjfkapdkoienihi?hl=en|React DevTools}
 *  component tree. This component is displayed as "ExperimentSDKContext.Provider".)
 *
 * It's highly recommended to pass in a type interface for stronger typing of experiment data.
 *
 * @param children the child elements of this component
 * @param sdkInstance Required. The singleton instance of {@link ExperimentSDK}
 *
 * @return {JSX.Element} Component with access to the {@link ExperimentSDKContext} values.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // SdkHooks.ts
 * // this is technically not necessary but helpful so you can easily get a correctly typed
 * // context throughout your application
 * import { ExperimentSDKContext, typesReact } from '@mongodb-js/mdb-experiment-js/react';
 * import { Types } from 'SomeParentComponent'
 *
 * export const useExperimentSdk = () => {
 *  return useContext(ExperimentSDKContext) as typesReact.ExperimentSDKContextType<Types>;
 * };
 *
 * // ProviderChildComponent.tsx component file
 * import { useExperimentSdk } from 'SdkHooks';
 *
 * return default function ProviderChildComponent() {
 *  const sdkContext = useExperimentSdk();
 *  const sdk = sdkContext.sdkInstance;
 *
 *  if (!sdk) { throw new Error('sdk should be initialized by now!') };
 *
 *  const sdkProps = sdk.getProperties();
 *
 *  return (
 *    <>
 *      context orgID is: {sdkProps.entityIds.orgId}<br />
 *      context environment is: {sdkProps.environment}
 *    </>
 *  );
 * }
 */
export default function ExperimentSDKProvider<T extends TypeData>({ children, sdkInstance, }: ExperimentSDKProviderProps<T>): JSX.Element;
//# sourceMappingURL=ExperimentSDKProvider.d.ts.map