import { AssignByPointsOptions, TypeData } from '../types';
import { BasicHookResponse } from './types';
/**
 * @description
 * A custom hook that makes a request to assign all experiments associated with the given allocation points via the API
 * for the SDK entity.
 *
 * Must be used in a child component of the {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or
 * else it throws an error.
 *
 * It wraps {@link ExperimentSDK.assignByPoints} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior.
 *
 * CAN make a POST API call. The hook returns info about the async SDK call status and SDK errors if any,
 * which is helpful for debugging. If the SDK throws an error, the hook will surface it as the "error"
 * property in the response but not re-throw it.
 *
 * Does NOT return assignment information--users should use the useAssignment hook for that.
 *
 * Intended usage:
 * Assign entities for experiments configured to use reusable allocation points in a React application.
 * Can take multiple points in 1 call.
 *
 * @param allocationPoints - Required. An array of allocation point name strings.
 * Please see {@link ExperimentSDK.assignByPoints} for more details.
 * @param {AssignByPointsOptions} options - Optional. Object with additional optional props, such as a "team" override
 * for logging purposes and a timeoutMs prop to define the API timeout.
 * Please see {@link ExperimentSDK.assignByPoints} for more details.
 *
 * @returns {BasicHookResponse} response - Object with asyncStatus and error props.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useAssignByPoints } from '@mongodb-js/mdb-experiment-js/react';
 * import { AllocationPointName, LoggerTeam } from 'SomeTypesFile';
 *
 * return default function ProviderChildComponent() {
 *  const allocationPointsArray: Array<AllocationPointName> = [
 *   AllocationPointName.CLUSTER_CARD_PAGE,
 *   AllocationPointName.REGISTRATION_SUCCESS_PAGE,
 * ];
 *
 *  const options: AssignByPointsOptions<LoggerTeam> = {
 *    team: LoggerTeam.Team1,
 *  };
 *
 *  const res = useAssignByPoints(allocationPointsArray, options);
 *
 *  return (
 *    <>
 *      async status: {res.asyncStatus}<br />
 *      error if any: {res.error}<br />
 *    </>
 *  );
 * }
 */
export default function useAssignByPoints<T extends TypeData>(allocationPoints: Array<T['allocationPointName']>, options?: AssignByPointsOptions<T['loggerTeam']>): BasicHookResponse;
//# sourceMappingURL=useAssignByPoints.d.ts.map