import { TypeData } from '../types';
import { UseAssignmentOptions, UseAssignmentResponse } from './types';
/**
 * @description
 * A custom hook that retrieves an entity's assignment in a given experiment. Must be used in
 * a child component of the {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or
 * else it throws an error.
 *
 * It wraps {@link ExperimentSDK.getAssignment} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior. It does augment the "options" optional parameter to also
 * be able to take in an array of {@link UseAssignmentOptions.hookDependencies} if desired.
 *
 * Also returns info about the async SDK call status and SDK errors if any, which is helpful for debugging. If the
 * SDK throws an error, the hook will surface it as the "error" property in the response but not re-throw it.
 *
 * This hook is race condition-aware and will automatically trigger a re-render with updated assignment data
 * if a subsequent assignment call happens that updates the internal state of the SDK.
 *
 * Intended usage:
 * To get an entity's experiment assignment information in a React application.
 *
 * @param experimentName Required. Please see {@link ExperimentSDK.getAssignment} for more details.
 * @param trackIsInSample Required. Please see {@link ExperimentSDK.getAssignment} for more details.
 * @param options Optional. Please see {@link ExperimentSDK.getAssignment} and {@link UseAssignmentOptions}
 * for more details.
 *
 * @return An object with {@link BasicHookResponse} info and an {@link SDKAssignment} object which can be null.
 * Even if an SDKAssignment object comes back, the entity may not be in the experiment--check
 * {@link SDKAssignment.assignmentData.isInSample} to be sure.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useAssignment } from '@mongodb-js/mdb-experiment-js/react';
 * import { ExperimentName } from 'SomeTypesFile';
 *
 * return default function ProviderChildComponent() {
 *  const res = useAssignment(ExperimentName.EXP_ONE, false);
 *
 *  return (
 *    <>
 *      async status: {res.asyncStatus}<br />
 *      error if any: {res.error}<br />
 *      assignment variant: {res.assignment?.assignmentData.variant}
 *    </>
 *  );
 * }
 */
export default function useAssignment<T extends TypeData>(experimentName: T['experimentName'], trackIsInSample: boolean, options?: UseAssignmentOptions<T>): UseAssignmentResponse<T>;
//# sourceMappingURL=useAssignment.d.ts.map