import { ExperimentAttributeValue, TypeData } from '../types';
/**
 * @description
 * A custom hook that given an attribute name, returns the value for attributeName from the local SDK state,
 * or the fallback value if none exists. Must be used in a child component of the
 * {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or else it throws an error.
 *
 * It wraps {@link ExperimentSDK.getExperimentAttribute} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior.
 *
 * This hook is race condition-aware and will automatically trigger a re-render with updated assignment data
 * if a subsequent assignment call happens that updates the internal state of the SDK.
 *
 * Intended usage:
 * To retrieve experiment attributes in a React application.
 *
 * @param {string} attributeName - Required. The attribute name.
 * Please see {@link ExperimentSDK.getExperimentAttribute} for more details.
 * @param {ExperimentAttributeValue} fallbackValue - Required. The fallback value to be returned if attributeName does
 * not exist in local SDK state. Please see {@link ExperimentSDK.getExperimentAttribute} for more details.
 *
 * @return An ExperimentAttributeValue for attributeName or fallbackValue if none exists.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useExperimentAttribute } from '@mongodb-js/mdb-experiment-js/react';
 * import { ExperimentAttributeName } from 'SomeTypesFile';
 *
 * return default function ProviderChildComponent() {
 *  const attribute = useExperimentAttribute(ExperimentAttributeName.SHOW_LEFT_NAV_LINK, false);
 *
 *  return (
 *    <>
 *      ...
 *    </>
 *  );
 * }
 */
export default function useExperimentAttribute<T extends TypeData>(attributeName: T['experimentAttributeName'], fallbackValue: ExperimentAttributeValue): ExperimentAttributeValue;
//# sourceMappingURL=useExperimentAttribute.d.ts.map