/**
 * The different values of "environment" in the SDK
 * This is used for, among other things, determining the root URL for backend calls
 */
export declare enum Environment {
    LOCAL = "local",
    E2E = "e2e",
    DEMOBOX = "demobox",
    DEV = "dev",
    QA = "qa",
    PROD = "prod"
}
/**
 * Commonly used status codes (for {@link AsyncStatus})
 * Currently we only create AsyncStatus objects for success states; errors are thrown
 * and bubble up instead, hence why only 20X status codes are represented here.
 */
export declare enum StatusCode {
    SUCCESS = 200,
    ACCEPTED = 202
}
/**
 * The different values of severity for logging
 */
export declare enum Severity {
    INFO = "info",
    WARNING = "warning",
    ERROR = "error"
}
/**
 * The different Entity units for experiments
 */
export declare enum EntityType {
    USER = "USER",
    GROUP = "GROUP",
    ORG = "ORG",
    HOST = "HOST",
    CLUSTER = "CLUSTER",
    TENANT = "TENANT"
}
export declare enum ExperimentViewedEventName {
    EXPERIMENT_VIEWED = "Experiment Viewed",
    EXPERIMENT_GHOSTVIEWED = "Experiment GhostViewed"
}
/**
 * An optional type interface consumers can pass in during initializiation
 * to enforce enums for Experiment data. It is highly encouraged to pass this typing
 * in.
 */
export type TypeData = {
    /**
     * Enum representing experiment names. Should match expected values for
     * {@link ExperimentAssignment.testName}
     * @example
     * enum ExperimentName {
     *  EXP_ONE = 'expOne',
     * };
     * const types: TypeData = {
     *  experimentName: ExperimentName,
     *  ...
     * }
     */
    experimentName: string;
    /**
     * Enum representing experiment variant names. Should match expected values for
     * {@link ExperimentAssignment.testGroupId}
     * @example
     * enum ExperimentVariantName {
     *  EXP_VARIANT_ONE = 'expVariantOne',
     * };
     * const types: TypeData = {
     *  experimentVariantName: ExperimentVariantName,
     *  ...
     * }
     */
    experimentVariantName: string;
    /**
     * Enum representing experiment attribute names
     * @example
     * enum ExperimentAttributeName {
     *  SHOW_LEFT_NAV_LINK = 'showLeftNavLink',
     * };
     * const types: TypeData = {
     *  experimentAttributeName: ExperimentAttributeName,
     *  ...
     * }
     */
    experimentAttributeName: string;
    /**
     * Enum representing allocation point names
     * @example
     * enum AllocationPointName {
     *  CLUSTER_CARD_PAGE = 'CLUSTER_CARD_PAGE',
     * };
     * const types: TypeData = {
     *  allocationPointName: AllocationPointName,
     *  ...
     * }
     */
    allocationPointName: string;
    /**
     * Type/Interface containing key/value pairs of properties that may be included in the
     * "Experiment Ghost/Viewed" event
     *
     * @example
     * export interface ExperimentViewedBaseEvent {
     *   test_name: TestName;
     *   test_group_name: TestGroupName;
     * }
     * interface ExperimentViewedPropertiesForExperimentA {
     *   aCustomProp: string;
     * }
     * interface ExperimentViewedPropertiesForExperimentB {
     *   aSecondCustomProp: string;
     *   aThirdCustomProp: string;
     * }
     * type ExperimentViewedAdditionalProperties =
     *   | ExperimentViewedPropertiesForExperimentA | ExperimentViewedPropertiesForExperimentB;
     * type ExperimentViewedEventProps =
     *   | ExperimentViewedBaseEvent
     *   | (ExperimentViewedBaseEvent & ExperimentViewedAdditionalProperties);
     *
     * const types: TypesToPassIn = {
     *   experimentViewedProps: ExperimentViewedEventProps,
     *   ...
     * }
     */
    experimentViewedProps: {
        [name: string]: string | number;
    };
    /**
     * Enum representing different teams that can be assigned application logs
     * @example
     * enum LoggerTeam {
     *  Team1 = 'Test Team 1',
     * };
     * const types: TypeData = {
     *  loggerTeam: LoggerTeam,
     *  ...
     * }
     */
    loggerTeam: string;
};
/**
 * A simple object representing the status of a response from an async call
 */
export interface AsyncStatus {
    statusCode: StatusCode;
    message?: string;
}
/**
 * An experiment assignment for a given entity and experiment.
 * This represents the raw assignment data fed into {@link ExperimentSDK.addExistingExperimentData}.
 * (FYI The below interface is taken from MMS: packages/types/abTest.ts)
 */
export interface ServerAssignment<ExperimentName, ExperimentVariantName> {
    /**
     * The date of the experiment assignment, in ms.
     * @example
     * "1658340252128"
     */
    assignmentDate: string;
    /**
     * The ID of the entity assigned.
     * @example
     * "621509aae911cb2e37ba91ca"
     */
    entityId: string;
    /**
     * The "type" of entity. Experiments are configured to allocate specific entity types.
     * @example
     * "ORG"
     */
    entityType: EntityType;
    /**
     * ID of the experiment assignment. Normally populated, but can be null
     * if the Assignment is for a LAUNCHED experiment.
     * @example
     * "62d8439c9ce6473793cff6ca"
     */
    id: string | null;
    /**
     * Experiment tag, set in the experiment configuration. Experiments on the same tag
     * are mutually exclusive.
     * @example
     * "activation"
     */
    tag: string;
    /**
     * The ID of the experiment configuration.
     * @example
     * "62bb810b61be7d017fcc2198"
     */
    testId: string;
    /**
     * The name of the experiment. Should be a value from the {@link TypeData.experimentName} enum.
     * @example
     * "ATLAS_SEARCH_IN_PROJECT_SIDE_NAV_20220620"
     */
    testName: ExperimentName;
    /**
     * The name of the assigned experiment variant for the entity.
     * (Confusingly is NOT an ObjectId.)
     * If defined, should be a value from the {@link TypeData.experimentVariantName} enum.
     * The "/assign" server response will have this always
     * defined as a string, but the "/params" and "/assignByPoint" endpoints may have "null" for an
     * experiment, which would mean the entity is NOT allocated into the experiment
     * (aka not in any of the variants, including control).
     *
     * @example
     * "atlasSearchProjectSideNavControl"
     */
    testGroupId: ExperimentVariantName | null;
    /**
     * The ID of the assigned experiment variant for the entity.
     * The "/assign" server response will have this always
     * defined as a string, but the "/params" and "/assignByPoint" endpoints may have "null" for an
     * experiment, which would mean the entity is NOT allocated into the experiment
     * (aka not in any of the variants, including control).
     *
     * @example
     * "62bb810b61be7d017fcc2196"
     */
    testGroupDatabaseId: string | null;
    /**
     * An object containing assignment metadata, which currently consists of 1 field (isLaunchedExperiment).
     * Should normally be present, though can be "null" for 1. older assignments, or 2. override assignments.
     *
     * @example
     * { isLaunchedExperiment: false }
     */
    meta: {
        isLaunchedExperiment: boolean;
    } | null;
}
/**
 * A GHOST experiment assignment for a given entity and experiment. Extends the base "ServerAssignment" type.
 * This represents the raw assignment data fed into {@link ExperimentSDK.addExistingExperimentData}.
 * (FYI The below interface is taken from MMS: packages/types/abTest.ts)
 */
export interface ServerGhostAssignment<ExperimentName, ExperimentVariantName> extends ServerAssignment<ExperimentName, ExperimentVariantName> {
    /**
     * The ID of the Holdout experiment which is responsible for the entity getting a
     * ghost assignment for the given test (aka the experiment represented by testName/testId).
     * Ghost assignments should always have this field populated.
     * (Ghost assignments are used for trackIsInSample functionality and can be ignored by most consumers.)
     *
     * @example
     * "645e70f9e40f6ce91c1efbaf"
     */
    linkedHoldoutTestId: string;
    /**
     * The name of the Holdout experiment which is responsible for the entity getting a
     * ghost assignment for the given test (aka the experiment represented by testName/testId).
     * Ghost assignments should always have this field populated.
     * NOT necessarily a {@link TypeData.experimentName} enum value, as Holdout experiments are
     * generally configured and managed outside of the client platform.
     * (Ghost assignments are used for trackIsInSample functionality and can be ignored by most consumers.)
     *
     * @example
     * "HOLDOUT_2Q2023"
     */
    linkedHoldoutTestName: string;
}
/**
 * A utility type representing both possible ServerAssignment types.
 */
export type ServerAssignmentUnionType<ExperimentName, ExperimentVariantName> = ServerAssignment<ExperimentName, ExperimentVariantName> | ServerGhostAssignment<ExperimentName, ExperimentVariantName>;
/**
 * Entity assignment data. Used in {@link SDKAssignment}, {@link SDKGhostAssignment}, and {@link SDKGenericAssignment}
 */
export interface AssignmentData<ExperimentVariantName> {
    /**
     * Represents if the entity has been allocated into the experiment. Should ALWAYS be used
     * to check if an entity is allocated in an experiment--just checking for the presence of the experiment name key
     * in SDK state isn't enough.
     */
    isInSample: boolean;
    /**
     * If the entity is allocated, the variant name they are assigned to.
     * Can be null if they are not allocated in the experiment.
     */
    variant: ExperimentVariantName | null;
}
/**
 * An experiment assignment for a given entity and experiment in the SDK.
 * This represents an assignment object in {@link ExperimentSDK.#assignmentsMap}
 */
export interface SDKAssignment<ExperimentName, ExperimentVariantName> {
    /**
     * Critical data about the specific entity's assignment
     */
    assignmentData: AssignmentData<ExperimentVariantName>;
    /**
     * All the information from the server about the experiment and the entity's assignment
     */
    experimentData: ServerAssignment<ExperimentName, ExperimentVariantName>;
}
/**
 * A GHOST experiment assignment for a given entity and experiment in the SDK.
 * This represents an assignment object in {@link ExperimentSDK.#ghostAssignmentsMap}
 */
export interface SDKGhostAssignment<ExperimentName, ExperimentVariantName> {
    /**
     * Critical data about the specific entity's assignment
     */
    assignmentData: AssignmentData<ExperimentVariantName>;
    /**
     * All the information from the server about the experiment and the entity's GHOST assignment
     */
    experimentData: ServerGhostAssignment<ExperimentName, ExperimentVariantName>;
}
/**
 * A utility type representing both possible SDK Assignment types.
 */
export type SDKAssignmentUnionType<ExperimentName, ExperimentVariantName> = SDKAssignment<ExperimentName, ExperimentVariantName> | SDKGhostAssignment<ExperimentName, ExperimentVariantName>;
/**
 * A utility interface that takes a generic R (either ServerAssignment or ServerGhostAssignment)
 * and returns a matching SDKAssignment.
 */
export interface SDKGenericAssignment<ExperimentName, ExperimentVariantName, R extends ServerAssignment<ExperimentName, ExperimentVariantName>> {
    /**
     * Critical data about the specific entity's assignment
     */
    assignmentData: AssignmentData<ExperimentVariantName>;
    /**
     * All the information from the server about the experiment and the entity's assignment.
     * Can be either a {@link ServerAssignment} or a {@link ServerGhostAssignment}
     */
    experimentData: R;
}
/**
 * An experiment attribute from the server. The values are all strings.
 * This represents the raw experiment attribute data fed into {@link ExperimentSDK.addExistingExperimentData}
 * (which takes cares of transforming the strings into booleans and numbers as needed).
 * (FYI The below interface is taken from MMS: js/admin/controlpanel/types/abTest.ts)
 */
export type ServerExperimentAttributes<ExperimentAttributeName extends string> = {
    [key in ExperimentAttributeName]?: string;
};
/**
 * Represents the types an Experiment Attribute in an experiment configuration can be.
 */
export type ExperimentAttributeValue = string | boolean | number;
/**
 * An experiment attribute in the SDK.
 * This represents an experiment attribute object in {@link ExperimentSDK.#experimentAttributesMap}
 */
export type SDKExperimentAttributes<ExperimentAttributeName extends string> = {
    [key in ExperimentAttributeName]?: ExperimentAttributeValue;
};
/**
 * A set of ID values. Each ID is treated as a distinct entity for experiments.
 * Experiment configuration dictates which entity ID it will use for allocation.
 */
export interface EntityIds {
    /**
     * All values below are strings representing an entity ID.
     * Each of these should be serializeable to an "ObjectId",
     * which is Mongodb's default ID class for a document.
     * @example
     * "621509aae911cb2e37ba91ca"
     */
    orgId?: string;
    groupId?: string;
    userId?: string;
    hostId?: string;
    clusterId?: string;
    tenantId?: string;
}
/**
 * The interface for a log message + metadata, for use with the {@link Logger}.
 */
export interface Log<LoggerTeam> {
    logMessage: string;
    severity: Severity;
    team?: LoggerTeam;
}
/**
 * Data ingested by the internal #log function in the SDK.
 */
export interface SDKLogOptions<LoggerTeam> extends Log<LoggerTeam> {
    additionalLogInfo?: Record<string, string | null | undefined>;
}
/**
 * A Logger object that can be used to monitor SDK health.
 */
export interface Logger<LoggerTeam> {
    /**
     * @description
     * Function to log a message to a log store
     *
     * Intended usage:
     * Call this to log
     *
     * @param {string} logMessage - Required
     * @param {Severity} severity - Required
     * @param {LoggerTeam} team
     *
     * @example
     * enum LoggerTeam {
     *  Team1 = 'Test Team 1',
     * };
     *
     * Logger.log({
     *  logMessage: 'There was an error',
     *  severity: Severity.ERROR,
     *  team: LoggerTeam.Team1
     * });
     */
    log: ({ logMessage, severity, team }: Log<LoggerTeam>) => void;
}
/**
 * Object representing Logger object and logging-related properties
 */
export interface LoggerOptions<LoggerTeam> {
    /** A Logger */
    logger: Logger<LoggerTeam>;
    /** The default team a log should be assigned to */
    defaultTeam: LoggerTeam;
}
/**
 * A Tracker object that can send data on client metrics.
 */
export interface Tracker<ExperimentViewedProps> {
    /**
     * @description
     * Function that broadcasts client-side analytics events
     *
     * Intended usage:
     * Used by the function `trackIsInSample` to broadcast 'Experiment Viewed' and 'Experiment GhostViewed' events
     *
     * @param {
     *   {
     *     eventName: 'Experiment Viewed',
     *     properties?: {},
     *     timeout?: number,
     *   }
     * } trackOptions - Required
     *
     * @return {Promise<void | Error | { message?: string }>}
     * Calling `track` will always return a promise.
     * - If the call is successful, the value of the promise will be void.
     * - If there is an error, the value of the promise will be the error.
     * - In some specific situations, the value of the promise will be an object with a key `message`.
     * -- {@link https://github.com/10gen/heliotrope|Heliotrope} returns these "objects with a message"
     * -- when it caches an analytics call (tries to make a track call before Heliotrope is
     * -- initialized), or when it attempts to make a track call when Heliotrope is not enabled.
     *
     * @example
     * `const trackPromise = this.#tracker.track({
     *   eventName: 'Experiment Viewed',
     *   properties: {
     *     customProperty: 'A Relevant Value',
     *   },
     *   timeout: 100,
     * });`
     *
     * Note: `this.#tracker.track()` will only be called via `ExperimentSDK.trackIsInSample({...})`, and not
     * by the SDK's consumers.
     *
     * Note: Any properties that are passed into the `properties` object will have to match the
     * `experimentViewedProps` type that was passed in when the SDK was initialized.
     *
     */
    track: (trackOptions: {
        eventName: ExperimentViewedEventName;
        properties?: ExperimentViewedProps;
        timeout?: number;
    }) => Promise<void | Error | {
        message?: string;
    }>;
}
/**
 * Object representing Tracker object and tracking-related properties
 */
export interface TrackerOptions<ExperimentViewedProps> {
    /** A Tracker */
    tracker: Tracker<ExperimentViewedProps>;
}
/**
 * Default props for the "Experiment Ghost/Viewed" event sent by trackIsInSample
 * Very similar to {@link ServerAssignment} except the keys are snake-case
 * and has 2 additional props: test_group_name and test_assignment
 *
 * In case it's an "Experiment GhostViewed" event, also has 2 more props related to
 * holdouts.
 */
export interface ExperimentViewedBaseEvent<T extends TypeData> {
    /**
     * See {@link ServerAssignment.testName} for more details
     *
     * @example
     * "ATLAS_SEARCH_IN_PROJECT_SIDE_NAV_20220620"
     */
    test_name: T['experimentName'];
    /**
     * See {@link ServerAssignment.testGroupId} for more details. However,
     * 1 key difference is that this value will always be defined.
     *
     * Worth reiterating that this is NOT an ObjectId value and has the same value
     * as {@link ExperimentViewedBaseEvent.test_group_name}.
     *
     * @example
     * "atlasSearchProjectSideNavControl"
     */
    test_group_id: T['experimentVariantName'];
    /**
     * Same as {@link ExperimentViewedBaseEvent.test_group_id}
     *
     * @example
     * "atlasSearchProjectSideNavControl"
     */
    test_group_name: T['experimentVariantName'];
    /**
     * See {@link ServerAssignment.entityType} for more details.
     *
     * @example
     * "ORG"
     */
    entity_type: EntityType;
    /**
     * See {@link ServerAssignment.entityId} for more details.
     *
     * @example
     * "621509aae911cb2e37ba91ca"
     */
    entity_id: string;
    /**
     * See {@link ServerAssignment.tag} for more details.
     *
     * @example
     * "activation"
     */
    test_tag: string;
    /**
     * See {@link ServerAssignment.assignmentDate} for more details.
     *
     * @example
     * "1658340252128"
     */
    assignment_date: string;
    /**
     * See {@link ServerAssignment.testGroupDatabaseId} for more details. However,
     * 1 key difference is that this value will always be defined.
     *
     * @example
     * "62bb810b61be7d017fcc2196"
     */
    test_group_database_id: string;
    /**
     * See {@link ServerAssignment.testId} for more details.
     *
     * @example
     * "62bb810b61be7d017fcc2198"
     */
    test_id: string;
    /**
     * A formatted string that contains the experiment name and variant.
     *
     * @example
     * "test_ATLAS_SEARCH_IN_PROJECT_SIDE_NAV_20220620_variant_atlasSearchProjectSideNavControl"
     */
    test_assignment: string;
    /**
     * See {@link ServerAssignment.linkedHoldoutTestId} for more details.
     * Should only be present for GHOST events.
     *
     * @example
     * "645e70f9e40f6ce91c1efbaf"
     */
    linked_holdout_test_id?: string;
    /**
     * See {@link ServerAssignment.linkedHoldoutTestName} for more details.
     * Should only be present for GHOST events.
     *
     * @example
     * "HOLDOUT_2Q2023"
     */
    linked_holdout_test_name?: string;
}
/**
 * Options to pass into the constructor
 */
export interface ConstructorOptions<T extends TypeData> {
    /** The entityId(s). Required. */
    entityIds: EntityIds;
    /** The environment the SDK is running in. Required. */
    environment: Environment;
    /** Logger-related properties */
    loggerOptions?: LoggerOptions<T['loggerTeam']>;
    /** Tracker-related properties */
    trackerOptions?: TrackerOptions<T['experimentViewedProps']>;
}
/**
 * Response object from ExperimentSDK.getProperties
 * (Very similar to {@link ConstructorOptions} except Logger and TrackerOptions can be null)
 */
export interface GetPropertiesResponse<T extends TypeData> {
    /** The entityId(s) of the SDK instance. */
    entityIds: EntityIds;
    /** Logger-related properties of the SDK instance */
    loggerOptions: LoggerOptions<T['loggerTeam']> | null;
    /** Tracker-related properties of the SDK instance */
    trackerOptions: TrackerOptions<T['experimentViewedProps']> | null;
    /** The environment of the SDK instance.. */
    environment: Environment;
}
/**
 * Server-formatted assignment array that's specific to the passed in list of possible experiment and variant names.
 */
export type ServerAssignments<T extends TypeData> = Array<ServerAssignment<T['experimentName'], T['experimentVariantName']>>;
/** Server-formatted map of experiment attribute keys to values. */
export type ServerExperimentAttributeMap<T extends TypeData> = ServerExperimentAttributes<T['experimentAttributeName']>;
/**
 * Object parameter for ExperimentSDK.addExistingExperimentData
 */
export interface ExistingData<T extends TypeData> {
    assignments?: ServerAssignments<T>;
    experimentAttributes?: ServerExperimentAttributeMap<T>;
    ghostAssignments?: Array<ServerGhostAssignment<T['experimentName'], T['experimentVariantName']>>;
}
/**
 * Object parameter for ExperimentSDK.addExperimentCalls, which is a dev-env-only function
 */
export interface AddExperimentCallsProps<T extends TypeData> {
    assignmentCalls?: Partial<Record<T['experimentName'], Promise<AsyncStatus>>>;
    allocationPointCalls?: Partial<Record<T['allocationPointName'], Promise<AsyncStatus>>>;
}
/**
 * Shared props that all functions can provide in their "options" objects
 */
interface BasicFunctionOptions<LoggerTeam> {
    /**
     * The "team" value that should be used for the logger
     * (if not passed, the "defaultTeam" from initialization is used)
     */
    team?: LoggerTeam;
}
/**
 * Represents additional options for ExperimentSDK.addExistingExperimentData
 */
export type AddExistingExperimentDataOptions<LoggerTeam> = BasicFunctionOptions<LoggerTeam>;
interface BasicAPICallingFunctionOptions<LoggerTeam> extends BasicFunctionOptions<LoggerTeam> {
    /**
     * An API timeout value, in milliseconds
     * (if not passed, a default value of 5 seconds is used)
     */
    timeoutMs?: number;
}
/**
 * Represents additional options for ExperimentSDK.getAssignments
 */
export interface GetAssignmentOptions<T extends TypeData> extends BasicAPICallingFunctionOptions<T['loggerTeam']> {
    /**
     * Custom properties that will be passed to "trackIsInSample" to be used in the
     * "Experiment Viewed" call
     */
    trackIsInSampleCustomProps?: T['experimentViewedProps'];
    /**
     * Set to true to use the entity generic mmsGetAssignmentV3 api method
     *
     * @default undefined which will use the deprecated mmsGetAssignment api function instead when unspecified
     *
     * @todo remove this property after the deprecated mmsGetAssignment api function is removed.
     *  Once the deprecated function is removed, by default all getAssignment requests should be using v3.
     */
    useV3Assignment?: boolean;
}
/**
 * Represents additional options for ExperimentSDK.assign
 */
export type AssignOptions<LoggerTeam> = BasicAPICallingFunctionOptions<LoggerTeam> & {
    /**
     * Specify the entity type to use with the new entity generic mmsAssignV3 api function
     *
     * @default undefined which will use the deprecated mmsAssign api function instead when unspecified
     *
     * @todo make this property required after the deprecated mmsAssign api function is removed.
     *  Once the deprecated function is removed, by default all assign requests will require an entity type
     */
    entityTypeForV3Assignment?: EntityType;
};
/**
 * Represents additional options for ExperimentSDK.assignByPoints
 * Right now it's aliased to the "AssignOptions" interface because the same options apply for this function.
 * However, in the future if the 2 option interfaces diverge, feel free to define this as its own
 * distinct interface.
 */
export type AssignByPointsOptions<LoggerTeam> = BasicAPICallingFunctionOptions<LoggerTeam> & {
    /**
     * Set to true to use the entity generic mmsAssignByPointsV3 api method
     *
     * @default undefined which will use the deprecated mmsAssignByPoints api function instead when unspecified
     *
     * @todo remove this property after the deprecated mmsAssignByPoints api function is removed.
     *  Once the deprecated function is removed, by default all assignByPoints requests should be using v3.
     */
    useV3Assignment?: boolean;
};
/** API Types below */
/**
 * A typing to confirm that ROOT_URLS has values for all the known Environments
 */
export type RootURLMapping<Environment extends string> = {
    [key in Environment]: string;
};
/**
 * Object parameter for api.callMMS (an internal API helper function)
 */
export interface CallMMSProps {
    /**
     * Fully formed URI string
     */
    uri: string;
    /**
     * List of allowed REST actions. Add additional types as needed.
     */
    action: 'GET' | 'POST';
    /**
     * Optional - POST requests can have a body, but GET requests cannot.
     */
    body?: Record<string, Array<string | EntityForExperimentation> | EntityForExperimentation>;
    /**
     * An API timeout value, in milliseconds
     * (if not passed, a default value of 5 seconds is used)
     */
    timeoutMs?: number;
}
/**
 * Shared props for MMS API calls
 */
export interface MMSApiProps {
    environment: Environment;
    timeoutMs?: number;
}
/**
 * Shared props for legacy MMS API assign calls that are not entity generic
 */
export interface MMSLegacyApiProps {
    groupId?: string;
    orgId?: string;
}
/**
 * Object parameter for api.mmsAssign
 */
export interface MMSAssignProps<T extends TypeData> extends MMSApiProps, MMSLegacyApiProps {
    experimentName: T['experimentName'];
}
/**
 * Object parameter for api.mmsAssignV3
 */
export interface MMSAssignV3Props<T extends TypeData> extends MMSApiProps {
    experimentName: T['experimentName'];
    entityType: EntityType;
    entityIds: EntityIds;
}
/**
 * Object parameter for api.mmsGetAssignment
 */
export interface MMSGetAssignmentProps<T extends TypeData> extends MMSApiProps, MMSLegacyApiProps {
    experimentName: T['experimentName'];
}
/**
 * Object parameter for api.mmsGetAssignmentV3
 */
export interface MMSGetAssignmentV3Props<T extends TypeData> extends MMSApiProps {
    experimentName: T['experimentName'];
    entityIds: EntityIds;
}
/**
 * Object parameter for api.mmsAssignByPoints
 */
export interface MMSAssignByPointsProps<T extends TypeData> extends MMSApiProps, MMSLegacyApiProps {
    allocationPoints: Array<T['allocationPointName']>;
}
/**
 * Object parameter for api.mmsAssignByPointsV3
 */
export interface MMSAssignByPointsV3Props<T extends TypeData> extends MMSApiProps {
    allocationPoints: Array<T['allocationPointName']>;
    entityIds: EntityIds;
}
/**
 * Expected shape of the MMS BE assign/assignByPoint response
 */
export interface MMSAssignmentResponse<T extends TypeData> {
    /**
     * Represents experiment assignment info from MMS for an entity. Each entry corresponds to 1 experiment.
     */
    data: Array<ServerAssignment<T['experimentName'], T['experimentVariantName']>>;
    /**
     * Represents experimentAttribute values from MMS for an entity. An experiment can have multiple (or 0)
     * experimentAttribute values. There is no way to tell in the response payload
     * what experiment an experimentAttribute is tied to.
     */
    experimentFeatureFlags: ServerExperimentAttributes<T['experimentAttributeName']>;
    /**
     * Represents "ghost" experiment assignment info from MMS for an entity.
     * Each entry corresponds to 1 experiment.
     */
    ghostAssignments: Array<ServerGhostAssignment<T['experimentName'], T['experimentVariantName']>>;
}
export type AssignmentsMap<T extends TypeData> = Partial<Record<T['experimentName'], SDKAssignment<T['experimentName'], T['experimentVariantName']>>>;
/**
 * Object that is passed to the new /v3 assignment endpoints to assign for experimentation.
 * Matches the shape of the EntityForExperimentation.java class in the MMS repo.
 *
 * @example
 *  {
 *     entityId: '55a0736f0cc6908d8bb565f2',
 *     entityType: 'ORG'
 *  }
 */
export type EntityForExperimentation = {
    entityId: string;
    entityType: EntityType;
};
export {};
//# sourceMappingURL=types.d.ts.map