import { EntityForExperimentation, EntityIds, EntityType } from './types';
/**
 * @description
 * Helper function for MMS API calls to get the correctly formatted query string, given a groupId or orgId
 *
 * Intended usage:
 * For API calls in this file
 *
 * @param - object containing optional string fields 'groupId',  'orgId', and 'experimentName'
 * @return string with the correctly formatted query param
 */
declare const createQueryString: ({ groupId, orgId, experimentName, }: {
    groupId?: string | undefined;
    orgId?: string | undefined;
    experimentName?: string | undefined;
}) => string;
/**
 * Helper that returns an object that satifies the EntityForExperimentation typing. These objects
 * are intended to be used as post body params for the new entity generic /v3 assign endpoints.
 * @param knownEntityIds is the sdk client's entityIds state presumably set with valid and known
 *  entity ids from the sdk's consuming application (ie: {orgId: '621509aae911cb2e37ba91ca'})
 * @param entityType is the entity type for the entity for experimentation
 * @returns EntityForExperimentation
 */
declare const createEntityForExperimentation: (knownEntityIds: EntityIds, entityType: EntityType) => EntityForExperimentation;
/**
 * Helper that returns a list of EntityForExperimentation objects. This list is intended to be passed
 * to the new /v3/assignmentsByAllocationPoints endpoint to assign entities by allocation points.
 * @param entityIds is the sdk client's entityIds state (ie: {orgId: '621509aae911cb2e37ba91ca'})
 * @returns list of EntityForExperimentation
 */
declare const createEntitesForExperimentationFromEntityIds: (entityIds: EntityIds) => Array<EntityForExperimentation>;
/**
 * Helper that creates a key that can access the sdk client's entityIds state (ie: orgId, userId, clusterId, etc.)
 * @param entityType is the entity type to create the key for
 * @returns key to access sdk client's entityId state
 */
declare const createEntityIdKey: (entityType: EntityType) => string;
/**
 * Given a GET assignment api url (ie: GET /v3/assignment/${testName}, GET /v2/assignment?experimentName=${testName}),
 * return the experiment name (or test name) that can be extracted from the url. The legacy /v2 endpoint has the
 * experiment name provided in the "experimentName" query param while the /v3 endpoint has it in the path parameter.
 *
 * @param url - the api
 * @returns experiment name from api URL, null if not found
 */
declare const getExperimentNameFromGetAssignmentApiUrl: (url: URL) => string | null;
/**
 * Given an input value, determine whether it is a valid non-empty string value
 * @param input to check
 * @returns true or false
 */
declare const isValidNonEmptyString: (input: unknown) => boolean;
export { createEntitesForExperimentationFromEntityIds, createEntityIdKey, createQueryString, createEntityForExperimentation, getExperimentNameFromGetAssignmentApiUrl, isValidNonEmptyString, };
//# sourceMappingURL=utils.d.ts.map